@@ -20,8 +20,8 @@
 
 #include "mainwindow.h"
 #include "languagemanager.h"
+#include "tiledapplication.h"
 
-#include <QApplication>
 #include <QDebug>
 #include <QtPlugin>
 
@@ -87,27 +87,19 @@ void parseCommandLineArguments(CommandLineOptions &options)
 int main(int argc, char *argv[])
 {
     /*
-     * On X11, Tiled uses the 'raster' graphics system, because the X11 native
-     * graphics system has performance problems with drawing the tile grid. We
-     * still want to allow people to override this with 'native', though.
+     * On X11, Tiled uses the 'raster' graphics system by default, because the
+     * X11 native graphics system has performance problems with drawing the
+     * tile grid.
      */
 #ifdef Q_WS_X11
-    {
-        bool graphicsSystemSpecified = false;
-        for (int i = 1; i < argc - 1; ++i) {
-            if (strcmp(argv[i], "-graphicssystem") == 0)
-                graphicsSystemSpecified = true;
-        }
-        if (!graphicsSystemSpecified)
-            QApplication::setGraphicsSystem(QLatin1String("raster"));
-    }
+    QApplication::setGraphicsSystem(QLatin1String("raster"));
 #endif
 
-    QApplication a(argc, argv);
+    TiledApplication a(argc, argv);
 
     a.setOrganizationDomain(QLatin1String("mapeditor.org"));
     a.setApplicationName(QLatin1String("Tiled"));
-    a.setApplicationVersion(QLatin1String("0.5.1"));
+    a.setApplicationVersion(QLatin1String("0.6.0"));
 #ifdef Q_WS_MAC
     a.setAttribute(Qt::AA_DontShowIconsInMenus);
 #endif
@@ -128,10 +120,13 @@ int main(int argc, char *argv[])
     MainWindow w;
     w.show();
 
+    QObject::connect(&a, SIGNAL(fileOpenRequest(QString)),
+                     &w, SLOT(openFile(QString)));
+
     if (!options.fileToOpen.isEmpty())
         w.openFile(options.fileToOpen);
     else
-        w.openLastFile();
+        w.openLastFiles();
 
     return a.exec();
 }
