@@ -6,6 +6,7 @@
  * Copyright 2009, Dennis Honeyman <arcticuno@gmail.com>
  * Copyright 2009, Christian Henz <chrhenz@gmx.de>
  * Copyright 2010, Andrew G. Crowell <overkill9999@gmail.com>
+ * Copyright 2010, Stefan Beller <stefanbeller@googlemail.com>
  *
  * This file is part of Tiled.
  *
@@ -27,8 +28,11 @@
 #include "ui_mainwindow.h"
 
 #include "aboutdialog.h"
+#include "automap.h"
 #include "addremovetileset.h"
 #include "clipboardmanager.h"
+#include "createobjecttool.h"
+#include "documentmanager.h"
 #include "eraser.h"
 #include "erasetiles.h"
 #include "bucketfilltool.h"
@@ -46,6 +50,7 @@
 #include "pluginmanager.h"
 #include "propertiesdialog.h"
 #include "resizedialog.h"
+#include "objectselectiontool.h"
 #include "offsetmapdialog.h"
 #include "preferences.h"
 #include "preferencesdialog.h"
@@ -62,6 +67,7 @@
 #include "undodock.h"
 #include "utils.h"
 #include "zoomable.h"
+#include "commandbutton.h"
 
 #include <QCloseEvent>
 #include <QFileDialog>
@@ -72,6 +78,9 @@
 #include <QUndoGroup>
 #include <QUndoStack>
 #include <QUndoView>
+#include <QImageReader>
+#include <QSignalMapper>
+#include <QShortcut>
 
 using namespace Tiled;
 using namespace Tiled::Internal;
@@ -87,11 +96,15 @@ MainWindow::MainWindow(QWidget *parent, Qt::WFlags flags)
     , mZoomLabel(new QLabel)
     , mStatusInfoLabel(new QLabel)
     , mClipboardManager(new ClipboardManager(this))
+    , mDocumentManager(new DocumentManager(this))
 {
     mUi->setupUi(this);
+    setCentralWidget(mDocumentManager->widget());
 
     PluginManager::instance()->loadPlugins();
 
+    Preferences *preferences = Preferences::instance();
+
     QIcon redoIcon(QLatin1String(":images/16x16/edit-redo.png"));
     QIcon undoIcon(QLatin1String(":images/16x16/edit-undo.png"));
 
@@ -112,41 +125,54 @@ MainWindow::MainWindow(QWidget *parent, Qt::WFlags flags)
     mUi->actionOpen->setIcon(openIcon);
     mUi->actionSave->setIcon(saveIcon);
 
-    mUndoGroup = new QUndoGroup(this);
-    QAction *undoAction = mUndoGroup->createUndoAction(this, tr("Undo"));
-    QAction *redoAction = mUndoGroup->createRedoAction(this, tr("Redo"));
+    QUndoGroup *undoGroup = mDocumentManager->undoGroup();
+    QAction *undoAction = undoGroup->createUndoAction(this, tr("Undo"));
+    QAction *redoAction = undoGroup->createRedoAction(this, tr("Redo"));
+#if QT_VERSION >= 0x040600
+    mUi->mainToolBar->setToolButtonStyle(Qt::ToolButtonFollowStyle);
+    mUi->actionNew->setPriority(QAction::LowPriority);
+    redoAction->setPriority(QAction::LowPriority);
+#endif
     redoAction->setIcon(redoIcon);
     undoAction->setIcon(undoIcon);
-    connect(mUndoGroup, SIGNAL(cleanChanged(bool)), SLOT(updateModified()));
+    redoAction->setIconText(tr("Redo"));
+    undoAction->setIconText(tr("Undo"));
+    connect(undoGroup, SIGNAL(cleanChanged(bool)), SLOT(updateWindowTitle()));
 
-    UndoDock *undoDock = new UndoDock(mUndoGroup, this);
+    UndoDock *undoDock = new UndoDock(undoGroup, this);
 
     addDockWidget(Qt::RightDockWidgetArea, mLayerDock);
     addDockWidget(Qt::RightDockWidgetArea, undoDock);
     tabifyDockWidget(undoDock, mLayerDock);
     addDockWidget(Qt::RightDockWidgetArea, mTilesetDock);
 
-    updateZoomLabel(mUi->mapView->zoomable()->scale());
-    connect(mUi->mapView->zoomable(), SIGNAL(scaleChanged(qreal)),
-            this, SLOT(updateZoomLabel(qreal)));
-
     statusBar()->addPermanentWidget(mZoomLabel);
 
-    mUi->actionNew->setShortcut(QKeySequence::New);
-    mUi->actionOpen->setShortcut(QKeySequence::Open);
-    mUi->actionSave->setShortcut(QKeySequence::Save);
-    mUi->actionSaveAs->setShortcut(QKeySequence::SaveAs);
-    mUi->actionClose->setShortcut(QKeySequence::Close);
+    mUi->actionNew->setShortcuts(QKeySequence::New);
+    mUi->actionOpen->setShortcuts(QKeySequence::Open);
+    mUi->actionSave->setShortcuts(QKeySequence::Save);
+    mUi->actionSaveAs->setShortcuts(QKeySequence::SaveAs);
+    mUi->actionClose->setShortcuts(QKeySequence::Close);
 #if QT_VERSION >= 0x040600
-    mUi->actionQuit->setShortcut(QKeySequence::Quit);
+    mUi->actionQuit->setShortcuts(QKeySequence::Quit);
 #endif
-    mUi->actionCut->setShortcut(QKeySequence::Cut);
-    mUi->actionCopy->setShortcut(QKeySequence::Copy);
-    mUi->actionPaste->setShortcut(QKeySequence::Paste);
-    undoAction->setShortcut(QKeySequence::Undo);
-    redoAction->setShortcut(QKeySequence::Redo);
-    mUi->actionZoomIn->setShortcut(QKeySequence::ZoomIn);
-    mUi->actionZoomOut->setShortcut(QKeySequence::ZoomOut);
+    mUi->actionCut->setShortcuts(QKeySequence::Cut);
+    mUi->actionCopy->setShortcuts(QKeySequence::Copy);
+    mUi->actionPaste->setShortcuts(QKeySequence::Paste);
+    undoAction->setShortcuts(QKeySequence::Undo);
+    redoAction->setShortcuts(QKeySequence::Redo);
+
+    mUi->actionShowGrid->setChecked(preferences->showGrid());
+    mUi->actionSnapToGrid->setChecked(preferences->snapToGrid());
+
+    // Make sure Ctrl+= also works for zooming in
+    QList<QKeySequence> keys = QKeySequence::keyBindings(QKeySequence::ZoomIn);
+    keys += QKeySequence(tr("Ctrl+="));
+    keys += QKeySequence(tr("+"));
+    mUi->actionZoomIn->setShortcuts(keys);
+    keys = QKeySequence::keyBindings(QKeySequence::ZoomOut);
+    keys += QKeySequence(tr("-"));
+    mUi->actionZoomOut->setShortcuts(keys);
 
     mUi->menuEdit->insertAction(mUi->actionCut, undoAction);
     mUi->menuEdit->insertAction(mUi->actionCut, redoAction);
@@ -159,9 +185,14 @@ MainWindow::MainWindow(QWidget *parent, Qt::WFlags flags)
     mUi->mainToolBar->addAction(undoAction);
     mUi->mainToolBar->addAction(redoAction);
 
+    mUi->mainToolBar->addSeparator();
+
+    mCommandButton = new CommandButton(this, mDocumentManager);
+    mUi->mainToolBar->addWidget(mCommandButton);
+
     mLayerMenu = new QMenu(tr("&Layer"), this);
     mLayerMenu->addAction(mActionHandler->actionAddTileLayer());
-    mLayerMenu->addAction(mActionHandler->actionAddObjectLayer());
+    mLayerMenu->addAction(mActionHandler->actionAddObjectGroup());
     mLayerMenu->addAction(mActionHandler->actionDuplicateLayer());
     mLayerMenu->addAction(mActionHandler->actionRemoveLayer());
     mLayerMenu->addSeparator();
@@ -181,6 +212,7 @@ MainWindow::MainWindow(QWidget *parent, Qt::WFlags flags)
     connect(mUi->actionSaveAsImage, SIGNAL(triggered()), SLOT(saveAsImage()));
     connect(mUi->actionExport, SIGNAL(triggered()), SLOT(exportAs()));
     connect(mUi->actionClose, SIGNAL(triggered()), SLOT(closeFile()));
+    connect(mUi->actionCloseAll, SIGNAL(triggered()), SLOT(closeAllFiles()));
     connect(mUi->actionQuit, SIGNAL(triggered()), SLOT(close()));
 
     connect(mUi->actionCut, SIGNAL(triggered()), SLOT(cut()));
@@ -189,12 +221,13 @@ MainWindow::MainWindow(QWidget *parent, Qt::WFlags flags)
     connect(mUi->actionPreferences, SIGNAL(triggered()),
             SLOT(openPreferences()));
 
-    connect(mUi->actionZoomIn, SIGNAL(triggered()),
-            mUi->mapView->zoomable(), SLOT(zoomIn()));
-    connect(mUi->actionZoomOut, SIGNAL(triggered()),
-            mUi->mapView->zoomable(), SLOT(zoomOut()));
-    connect(mUi->actionZoomNormal, SIGNAL(triggered()),
-            mUi->mapView->zoomable(), SLOT(resetZoom()));
+    connect(mUi->actionShowGrid, SIGNAL(toggled(bool)),
+            preferences, SLOT(setShowGrid(bool)));
+    connect(mUi->actionSnapToGrid, SIGNAL(toggled(bool)),
+            preferences, SLOT(setSnapToGrid(bool)));
+    connect(mUi->actionZoomIn, SIGNAL(triggered()), SLOT(zoomIn()));
+    connect(mUi->actionZoomOut, SIGNAL(triggered()), SLOT(zoomOut()));
+    connect(mUi->actionZoomNormal, SIGNAL(triggered()), SLOT(zoomNormal()));
 
     connect(mUi->actionNewTileset, SIGNAL(triggered()), SLOT(newTileset()));
     connect(mUi->actionAddExternalTileset, SIGNAL(triggered()),
@@ -203,6 +236,7 @@ MainWindow::MainWindow(QWidget *parent, Qt::WFlags flags)
     connect(mUi->actionOffsetMap, SIGNAL(triggered()), SLOT(offsetMap()));
     connect(mUi->actionMapProperties, SIGNAL(triggered()),
             SLOT(editMapProperties()));
+    connect(mUi->actionAutoMap, SIGNAL(triggered()), SLOT(autoMap()));
 
     connect(mActionHandler->actionLayerProperties(), SIGNAL(triggered()),
             SLOT(editLayerProperties()));
@@ -243,30 +277,28 @@ MainWindow::MainWindow(QWidget *parent, Qt::WFlags flags)
     setThemeIcon(mUi->actionMapProperties, "document-properties");
     setThemeIcon(mUi->actionAbout, "help-about");
 
-    mScene = new MapScene(this);
-    mUi->mapView->setScene(mScene);
-    mUi->mapView->centerOn(0, 0);
-#ifdef Q_OS_MAC
-    mUi->mapView->setFrameStyle(QFrame::NoFrame);
-#endif
-
-    mUi->actionShowGrid->setChecked(mScene->isGridVisible());
-    connect(mUi->actionShowGrid, SIGNAL(toggled(bool)),
-            mScene, SLOT(setGridVisible(bool)));
-
     mStampBrush = new StampBrush(this);
     mBucketFillTool = new BucketFillTool(this);
+    CreateObjectTool *tileObjectsTool = new CreateObjectTool(
+            CreateObjectTool::TileObjects, this);
+    CreateObjectTool *areaObjectsTool = new CreateObjectTool(
+            CreateObjectTool::AreaObjects, this);
 
     connect(mTilesetDock, SIGNAL(currentTilesChanged(const TileLayer*)),
             this, SLOT(setStampBrush(const TileLayer*)));
     connect(mStampBrush, SIGNAL(currentTilesChanged(const TileLayer*)),
             this, SLOT(setStampBrush(const TileLayer*)));
+    connect(mTilesetDock, SIGNAL(currentTileChanged(Tile*)),
+            tileObjectsTool, SLOT(setTile(Tile*)));
 
     ToolManager *toolManager = ToolManager::instance();
     toolManager->registerTool(mStampBrush);
     toolManager->registerTool(mBucketFillTool);
     toolManager->registerTool(new Eraser(this));
     toolManager->registerTool(new SelectionTool(this));
+    toolManager->registerTool(new ObjectSelectionTool(this));
+    toolManager->registerTool(areaObjectsTool);
+    toolManager->registerTool(tileObjectsTool);
 
     addToolBar(toolManager->toolBar());
 
@@ -281,16 +313,22 @@ MainWindow::MainWindow(QWidget *parent, Qt::WFlags flags)
 
     connect(mClipboardManager, SIGNAL(hasMapChanged()), SLOT(updateActions()));
 
+    connect(mDocumentManager, SIGNAL(currentDocumentChanged(MapDocument*)),
+            SLOT(mapDocumentChanged(MapDocument*)));
+    connect(mDocumentManager, SIGNAL(documentCloseRequested(int)),
+            this, SLOT(closeMapDocument(int)));
+
     updateActions();
     readSettings();
+    setupQuickStamps();
 }
 
 MainWindow::~MainWindow()
 {
-    writeSettings();
-
-    setMapDocument(0);
+    cleanQuickStamps();
+    mDocumentManager->closeAllDocuments();
 
+    AutomaticMappingManager::deleteInstance();
     ToolManager::deleteInstance();
     TilesetManager::deleteInstance();
     Preferences::deleteInstance();
@@ -305,13 +343,15 @@ void MainWindow::commitData(QSessionManager &manager)
     // Play nice with session management and cancel shutdown process when user
     // requests this
     if (manager.allowsInteraction())
-        if (!confirmSave())
+        if (!confirmAllSave())
             manager.cancel();
 }
 
 void MainWindow::closeEvent(QCloseEvent *event)
 {
-    if (confirmSave())
+    writeSettings();
+
+    if (confirmAllSave())
         event->accept();
     else
         event->ignore();
@@ -339,32 +379,47 @@ void MainWindow::dragEnterEvent(QDragEnterEvent *e)
 
 void MainWindow::dropEvent(QDropEvent *e)
 {
-    openFile(e->mimeData()->urls().at(0).toLocalFile());
+    const QString file = e->mimeData()->urls().at(0).toLocalFile();
+    const QString extension = QFileInfo(file).suffix();
+
+    // Treat file as a tileset if it is an image. Use the extension here because
+    // QImageReader::imageFormat() treats tmx files as svg
+    const QList<QByteArray> formats = QImageReader::supportedImageFormats();
+    foreach (const QByteArray &format, formats) {
+        if (extension.compare(QString::fromLatin1(format), Qt::CaseInsensitive) == 0) {
+            newTileset(file);
+            return;
+        }
+    }
+
+    // Treat file as a map otherwise
+    openFile(file);
 }
 
 void MainWindow::newMap()
 {
-    if (!confirmSave())
-        return;
-
     NewMapDialog newMapDialog(this);
     MapDocument *mapDocument = newMapDialog.createMap();
 
     if (!mapDocument)
         return;
 
-    setMapDocument(mapDocument);
-    mUi->mapView->centerOn(0, 0);
-
-    updateActions();
+    addMapDocument(mapDocument);
 }
 
 bool MainWindow::openFile(const QString &fileName,
                           MapReaderInterface *mapReader)
 {
-    if (fileName.isEmpty() || !confirmSave())
+    if (fileName.isEmpty())
         return false;
 
+    // Select existing document if this file is already open
+    int documentIndex = mDocumentManager->findDocument(fileName);
+    if (documentIndex != -1) {
+        mDocumentManager->switchToDocument(documentIndex);
+        return true;
+    }
+
     TmxMapReader tmxMapReader;
 
     if (!mapReader && !tmxMapReader.supportsFile(fileName)) {
@@ -391,30 +446,70 @@ bool MainWindow::openFile(const QString &fileName,
         return false;
     }
 
-    setMapDocument(new MapDocument(map, fileName));
-    mUi->mapView->centerOn(0, 0);
-
-    updateActions();
+    addMapDocument(new MapDocument(map, fileName));
+    setRecentFile(fileName);
     return true;
 }
 
-void MainWindow::openLastFile()
+bool MainWindow::openFile(const QString &fileName)
+{
+    return openFile(fileName, 0);
+}
+
+void MainWindow::openLastFiles()
 {
     const QStringList files = recentFiles();
 
-    if (!files.isEmpty() && openFile(files.first())) {
-        // Restore camera to the previous position
-        mSettings.beginGroup(QLatin1String("mainwindow"));
-        qreal scale = mSettings.value(QLatin1String("mapScale")).toDouble();
-        if (scale > 0)
-            mUi->mapView->zoomable()->setScale(scale);
+    mSettings.beginGroup(QLatin1String("recentFiles"));
 
-        const int hor = mSettings.value(QLatin1String("scrollX")).toInt();
-        const int ver = mSettings.value(QLatin1String("scrollY")).toInt();
-        mUi->mapView->horizontalScrollBar()->setSliderPosition(hor);
-        mUi->mapView->verticalScrollBar()->setSliderPosition(ver);
-        mSettings.endGroup();
+    int openCount = mSettings.value(QLatin1String("recentOpenedFiles"), 1).toInt();
+
+    QStringList mapScales = mSettings.value(
+                            QLatin1String("mapScale")).toStringList();
+    QStringList scrollX = mSettings.value(
+                          QLatin1String("scrollX")).toStringList();
+    QStringList scrollY = mSettings.value(
+                          QLatin1String("scrollY")).toStringList();
+    QStringList selectedLayer = mSettings.value(
+                                QLatin1String("selectedLayer")).toStringList();
+
+    for (int i = 0; i < openCount; i++) {
+        if (!(i < files.size()))
+            break;
+        if (!(i < mapScales.size()))
+            continue;
+        if (!(i < scrollX.size()))
+            continue;
+        if (!(i < scrollY.size()))
+            continue;
+        if (!(i < selectedLayer.size()))
+            continue;
+
+        if (openFile(files.at(i))) {
+            MapView *mapView = mDocumentManager->currentMapView();
+
+            // Restore camera to the previous position
+            qreal scale = mapScales.at(i).toDouble();
+            if (scale > 0)
+                mapView->zoomable()->setScale(scale);
+
+            const int hor = scrollX.at(i).toInt();
+            const int ver = scrollY.at(i).toInt();
+            mapView->horizontalScrollBar()->setSliderPosition(hor);
+            mapView->verticalScrollBar()->setSliderPosition(ver);
+
+            int layer = selectedLayer.at(i).toInt();
+            if (layer > 0 && layer < mMapDocument->map()->layerCount())
+                mMapDocument->setCurrentLayer(layer);
+        }
     }
+    QString lastActiveDocument =
+            mSettings.value(QLatin1String("lastActive")).toString();
+    int documentIndex = mDocumentManager->findDocument(lastActiveDocument);
+    if (documentIndex != -1)
+        mDocumentManager->switchToDocument(documentIndex);
+
+    mSettings.endGroup();
 }
 
 void MainWindow::openFile()
@@ -457,11 +552,7 @@ bool MainWindow::saveFile(const QString &fileName)
     if (!mMapDocument)
         return false;
 
-    Preferences *prefs = Preferences::instance();
-
     TmxMapWriter mapWriter;
-    mapWriter.setLayerDataFormat(prefs->layerDataFormat());
-    mapWriter.setDtdEnabled(prefs->dtdEnabled());
 
     if (!mapWriter.write(mMapDocument->map(), fileName)) {
         QMessageBox::critical(this, tr("Error Saving Map"),
@@ -471,14 +562,19 @@ bool MainWindow::saveFile(const QString &fileName)
 
     mMapDocument->undoStack()->setClean();
     mMapDocument->setFileName(fileName);
-    setCurrentFileName(fileName);
+    setRecentFile(fileName);
     return true;
 }
 
 bool MainWindow::saveFile()
 {
-    if (mCurrentFileName.endsWith(QLatin1String(".tmx")))
-        return saveFile(mCurrentFileName);
+    if (!mMapDocument)
+        return false;
+
+    const QString currentFileName = mMapDocument->fileName();
+
+    if (currentFileName.endsWith(QLatin1String(".tmx"), Qt::CaseInsensitive))
+        return saveFile(currentFileName);
     else
         return saveFileAs();
 }
@@ -508,7 +604,7 @@ bool MainWindow::saveFileAs()
 
 bool MainWindow::confirmSave()
 {
-    if (!mMapDocument || mMapDocument->undoStack()->isClean())
+    if (!mMapDocument || !mMapDocument->isModified())
         return true;
 
     int ret = QMessageBox::warning(
@@ -525,14 +621,26 @@ bool MainWindow::confirmSave()
     }
 }
 
+bool MainWindow::confirmAllSave()
+{
+    for (int i = 0; i < mDocumentManager->documentCount(); i++) {
+        mDocumentManager->switchToDocument(i);
+        if (!confirmSave())
+            return false;
+    }
+
+    return true;
+}
+
 void MainWindow::saveAsImage()
 {
     if (!mMapDocument)
         return;
 
+    MapView *mapView = mDocumentManager->currentMapView();
     SaveAsImageDialog dialog(mMapDocument,
-                             mCurrentFileName,
-                             mUi->mapView->zoomable()->scale(),
+                             mMapDocument->fileName(),
+                             mapView->zoomable()->scale(),
                              this);
     dialog.exec();
 }
@@ -577,7 +685,8 @@ void MainWindow::exportAs()
 
     // Also support exporting to the TMX map format when requested
     TmxMapWriter tmxMapWriter;
-    if (!chosenWriter && fileName.endsWith(QLatin1String(".tmx")))
+    if (!chosenWriter && fileName.endsWith(QLatin1String(".tmx"),
+                                           Qt::CaseInsensitive))
         chosenWriter = &tmxMapWriter;
 
     if (!chosenWriter) {
@@ -597,10 +706,14 @@ void MainWindow::exportAs()
 
 void MainWindow::closeFile()
 {
-    if (confirmSave()) {
-        setMapDocument(0);
-        updateActions();
-    }
+    if (confirmSave())
+        mDocumentManager->closeCurrentDocument();
+}
+
+void MainWindow::closeAllFiles()
+{
+    if (confirmAllSave())
+        mDocumentManager->closeAllDocuments();
 }
 
 void MainWindow::cut()
@@ -644,41 +757,32 @@ void MainWindow::paste()
     if (!mMapDocument)
         return;
 
-    if (Map *map = mClipboardManager->map()) {
-        // We can currently only handle maps with a single tile layer
-        if (map->layerCount() == 1) {
-            if (TileLayer *layer = dynamic_cast<TileLayer*>(map->layerAt(0))) {
-                QList<QUndoCommand*> addTilesetCommands;
+    Map *map = mClipboardManager->map();
+    if (!map)
+        return;
 
-                // Add tilesets that are not yet part of this map
-                foreach (Tileset *tileset, map->tilesets()) {
-                    if (!mMapDocument->map()->tilesets().contains(tileset)) {
-                        addTilesetCommands.append(new AddTileset(mMapDocument,
-                                                                 tileset));
-                    }
-                }
-                if (!addTilesetCommands.isEmpty()) {
-                    QUndoStack *undoStack = mMapDocument->undoStack();
-                    undoStack->beginMacro(tr("Add Tilesets"));
-                    foreach (QUndoCommand *command, addTilesetCommands)
-                        mMapDocument->undoStack()->push(command);
-                    undoStack->endMacro();
-                }
-
-                // Reset selection and paste into the stamp brush
-                mActionHandler->selectNone();
-                setStampBrush(layer);
-                ToolManager::instance()->selectTool(mStampBrush);
-
-                delete map;
-                return;
-            }
-        }
-
-        // Need to also clean up the tilesets since they didn't get an owner
+    // We can currently only handle maps with a single tile layer
+    if (!(map->layerCount() == 1 && map->layerAt(0)->asTileLayer())) {
+        // Need to clean up the tilesets since they didn't get an owner
         qDeleteAll(map->tilesets());
         delete map;
+        return;
     }
+
+    TilesetManager *tilesetManager = TilesetManager::instance();
+    tilesetManager->addReferences(map->tilesets());
+
+    mMapDocument->unifyTilesets(map);
+
+    TileLayer *tileLayer = map->layerAt(0)->asTileLayer();
+
+    // Reset selection and paste into the stamp brush
+    mActionHandler->selectNone();
+    setStampBrush(tileLayer);
+    ToolManager::instance()->selectTool(mStampBrush);
+
+    tilesetManager->removeReferences(map->tilesets());
+    delete map;
 }
 
 void MainWindow::openPreferences()
@@ -687,14 +791,36 @@ void MainWindow::openPreferences()
     preferencesDialog.exec();
 }
 
-void MainWindow::newTileset()
+void MainWindow::zoomIn()
+{
+    if (MapView *mapView = mDocumentManager->currentMapView())
+        mapView->zoomable()->zoomIn();
+}
+
+void MainWindow::zoomOut()
+{
+    if (MapView *mapView = mDocumentManager->currentMapView())
+        mapView->zoomable()->zoomOut();
+}
+
+void MainWindow::zoomNormal()
+{
+    if (MapView *mapView = mDocumentManager->currentMapView())
+        mapView->zoomable()->resetZoom();
+}
+
+void MainWindow::newTileset(const QString &path)
 {
     if (!mMapDocument)
         return;
 
     Map *map = mMapDocument->map();
 
-    NewTilesetDialog newTileset(fileDialogStartLocation(), this);
+    QString startLocation = path.isEmpty()
+                            ? fileDialogStartLocation()
+                            : path;
+
+    NewTilesetDialog newTileset(startLocation, this);
     newTileset.setTileWidth(map->tileWidth());
     newTileset.setTileHeight(map->tileHeight());
 
@@ -766,15 +892,19 @@ void MainWindow::editMapProperties()
     if (!mMapDocument)
         return;
     PropertiesDialog propertiesDialog(tr("Map"),
-                                      mMapDocument->map()->properties(),
+                                      mMapDocument->map(),
                                       mMapDocument->undoStack(),
                                       this);
     propertiesDialog.exec();
 }
 
-void MainWindow::updateModified()
+void MainWindow::autoMap()
 {
-    setWindowModified(!mUndoGroup->isClean());
+    AutomaticMappingManager::instance()->automap();
+    QString error = AutomaticMappingManager::instance()->errorString();
+    if (!error.isEmpty()) {
+        QMessageBox::critical(this, tr("Automatic Mapping"), error);
+    }
 }
 
 void MainWindow::openRecentFile()
@@ -786,7 +916,8 @@ void MainWindow::openRecentFile()
 
 QStringList MainWindow::recentFiles() const
 {
-    return mSettings.value(QLatin1String("recentFiles")).toStringList();
+    QVariant v = mSettings.value(QLatin1String("recentFiles/fileNames"));
+    return v.toStringList();
 }
 
 QString MainWindow::fileDialogStartLocation() const
@@ -809,13 +940,17 @@ void MainWindow::setRecentFile(const QString &fileName)
     while (files.size() > MaxRecentFiles)
         files.removeLast();
 
-    mSettings.setValue(QLatin1String("recentFiles"), files);
+    mSettings.beginGroup(QLatin1String("recentFiles"));
+    mSettings.setValue(QLatin1String("fileNames"), files);
+    mSettings.endGroup();
     updateRecentFiles();
 }
 
 void MainWindow::clearRecentFiles()
 {
-    mSettings.setValue(QLatin1String("recentFiles"), QStringList());
+    mSettings.beginGroup(QLatin1String("recentFiles"));
+    mSettings.setValue(QLatin1String("fileNames"), QStringList());
+    mSettings.endGroup();
     updateRecentFiles();
 }
 
@@ -853,6 +988,10 @@ void MainWindow::updateActions()
             Layer *layer = mMapDocument->map()->layerAt(currentLayer);
             tileLayerSelected = dynamic_cast<TileLayer*>(layer) != 0;
         }
+
+        mCommandButton->setEnabled(true);
+    } else {
+        mCommandButton->setEnabled(false);
     }
 
     const bool mapInClipboard = mClipboardManager->hasMap();
@@ -862,6 +1001,7 @@ void MainWindow::updateActions()
     mUi->actionSaveAsImage->setEnabled(map);
     mUi->actionExport->setEnabled(map);
     mUi->actionClose->setEnabled(map);
+    mUi->actionCloseAll->setEnabled(map);
     mUi->actionCut->setEnabled(tileLayerSelected && !selection.isEmpty());
     mUi->actionCopy->setEnabled(tileLayerSelected && !selection.isEmpty());
     mUi->actionPaste->setEnabled(tileLayerSelected && mapInClipboard);
@@ -870,16 +1010,25 @@ void MainWindow::updateActions()
     mUi->actionResizeMap->setEnabled(map);
     mUi->actionOffsetMap->setEnabled(map);
     mUi->actionMapProperties->setEnabled(map);
+    mUi->actionAutoMap->setEnabled(map);
+
+    updateZoomLabel(); // for the zoom actions
 }
 
-void MainWindow::updateZoomLabel(qreal scale)
+void MainWindow::updateZoomLabel()
 {
-    const Zoomable *zoomable = mUi->mapView->zoomable();
-    mUi->actionZoomIn->setEnabled(zoomable->canZoomIn());
-    mUi->actionZoomOut->setEnabled(zoomable->canZoomOut());
+    MapView *mapView = mDocumentManager->currentMapView();
+    const Zoomable *zoomable = mapView ? mapView->zoomable() : 0;
+    const qreal scale = zoomable ? zoomable->scale() : 1;
+
+    mUi->actionZoomIn->setEnabled(zoomable && zoomable->canZoomIn());
+    mUi->actionZoomOut->setEnabled(zoomable && zoomable->canZoomOut());
     mUi->actionZoomNormal->setEnabled(scale != 1);
 
-    mZoomLabel->setText(tr("%1%").arg(scale * 100));
+    if (zoomable)
+        mZoomLabel->setText(tr("%1%").arg(scale * 100));
+    else
+        mZoomLabel->setText(QString());
 }
 
 void MainWindow::editLayerProperties()
@@ -917,14 +1066,35 @@ void MainWindow::writeSettings()
     mSettings.beginGroup(QLatin1String("mainwindow"));
     mSettings.setValue(QLatin1String("geometry"), saveGeometry());
     mSettings.setValue(QLatin1String("state"), saveState());
-    mSettings.setValue(QLatin1String("gridVisible"),
-                       mUi->actionShowGrid->isChecked());
-    mSettings.setValue(QLatin1String("mapScale"),
-                       mUi->mapView->zoomable()->scale());
-    mSettings.setValue(QLatin1String("scrollX"),
-                       mUi->mapView->horizontalScrollBar()->sliderPosition());
-    mSettings.setValue(QLatin1String("scrollY"),
-                       mUi->mapView->verticalScrollBar()->sliderPosition());
+    mSettings.endGroup();
+
+    mSettings.beginGroup(QLatin1String("recentFiles"));
+    mSettings.setValue(QLatin1String("recentOpenedFiles"),
+                       mDocumentManager->documentCount());
+
+    if (MapDocument *document = mDocumentManager->currentDocument())
+        mSettings.setValue(QLatin1String("lastActive"), document->fileName());
+
+    QStringList mapScales;
+    QStringList scrollX;
+    QStringList scrollY;
+    QStringList selectedLayer;
+    for (int i = 0; i < mDocumentManager->documentCount(); i++) {
+        mDocumentManager->switchToDocument(i);
+        MapView *mapView = mDocumentManager->currentMapView();
+
+        mapScales.append(QString::number(mapView->zoomable()->scale()));
+        scrollX.append(QString::number(
+                       mapView->horizontalScrollBar()->sliderPosition()));
+        scrollY.append(QString::number(
+                       mapView->verticalScrollBar()->sliderPosition()));
+        selectedLayer.append(QString::number(mMapDocument->currentLayer()));
+
+    }
+    mSettings.setValue(QLatin1String("mapScale"), mapScales);
+    mSettings.setValue(QLatin1String("scrollX"), scrollX);
+    mSettings.setValue(QLatin1String("scrollY"), scrollY);
+    mSettings.setValue(QLatin1String("selectedLayer"), selectedLayer);
     mSettings.endGroup();
 }
 
@@ -938,50 +1108,42 @@ void MainWindow::readSettings()
         resize(800, 600);
     restoreState(mSettings.value(QLatin1String("state"),
                                  QByteArray()).toByteArray());
-    mUi->actionShowGrid->setChecked(
-            mSettings.value(QLatin1String("gridVisible"), true).toBool());
     mSettings.endGroup();
     updateRecentFiles();
 }
 
-void MainWindow::setCurrentFileName(const QString &fileName)
+void MainWindow::updateWindowTitle()
 {
-    mCurrentFileName = fileName;
-    setWindowFilePath(mCurrentFileName);
-    setWindowTitle(tr("%1[*] - Tiled").arg(QFileInfo(fileName).fileName()));
-    setRecentFile(mCurrentFileName);
+    if (mMapDocument) {
+        setWindowTitle(tr("[*]%1 - Tiled").arg(mMapDocument->displayName()));
+        setWindowFilePath(mMapDocument->fileName());
+        setWindowModified(mMapDocument->isModified());
+    } else {
+        setWindowTitle(QApplication::applicationName());
+        setWindowFilePath(QString());
+        setWindowModified(false);
+    }
 }
 
-void MainWindow::setMapDocument(MapDocument *mapDocument)
+void MainWindow::addMapDocument(MapDocument *mapDocument)
 {
-    if (mMapDocument)
-        mUndoGroup->removeStack(mMapDocument->undoStack());
+    mDocumentManager->addDocument(mapDocument);
 
-    mActionHandler->setMapDocument(mapDocument);
-    mScene->setMapDocument(mapDocument);
-    mLayerDock->setMapDocument(mapDocument);
-    mTilesetDock->setMapDocument(mapDocument);
-    mStampBrush->setMapDocument(mapDocument);
-    mBucketFillTool->setMapDocument(mapDocument);
+    connect(mapDocument, SIGNAL(currentLayerChanged(int)),
+            SLOT(updateActions()));
+    connect(mapDocument, SIGNAL(tileSelectionChanged(QRegion,QRegion)),
+            SLOT(updateActions()));
 
-    // TODO: Add support for multiple map documents
-    delete mMapDocument;
-    mMapDocument = mapDocument;
+    MapView *mapView = mDocumentManager->currentMapView();
+    connect(mapView->zoomable(), SIGNAL(scaleChanged(qreal)),
+            this, SLOT(updateZoomLabel()));
 
-    if (mMapDocument) {
-        setCurrentFileName(mMapDocument->fileName());
+    Preferences *prefs = Preferences::instance();
 
-        connect(mapDocument, SIGNAL(currentLayerChanged(int)),
-                SLOT(updateActions()));
-        connect(mapDocument, SIGNAL(tileSelectionChanged(QRegion,QRegion)),
-                SLOT(updateActions()));
-
-        QUndoStack *undoStack = mMapDocument->undoStack();
-        mUndoGroup->addStack(undoStack);
-        mUndoGroup->setActiveStack(undoStack);
-    } else {
-        setCurrentFileName(QString());
-    }
+    MapScene *mapScene = mapView->mapScene();
+    mapScene->setGridVisible(prefs->showGrid());
+    connect(prefs, SIGNAL(showGridChanged(bool)),
+            mapScene, SLOT(setGridVisible(bool)));
 }
 
 void MainWindow::aboutTiled()
@@ -992,11 +1154,140 @@ void MainWindow::aboutTiled()
 
 void MainWindow::retranslateUi()
 {
-    if (!mCurrentFileName.isEmpty()) {
-        const QString fileName = QFileInfo(mCurrentFileName).fileName();
-        setWindowTitle(tr("%1[*] - Tiled").arg(fileName));
-    }
+    updateWindowTitle();
 
     mLayerMenu->setTitle(tr("&Layer"));
     mActionHandler->retranslateUi();
 }
+
+void MainWindow::mapDocumentChanged(MapDocument *mapDocument)
+{
+    mMapDocument = mapDocument;
+
+    mActionHandler->setMapDocument(mMapDocument);
+    mLayerDock->setMapDocument(mMapDocument);
+    mTilesetDock->setMapDocument(mMapDocument);
+    AutomaticMappingManager::instance()->setMapDocument(mMapDocument);
+
+    updateWindowTitle();
+    updateActions();
+}
+
+void MainWindow::setupQuickStamps()
+{
+    QList<int> keys;
+    keys << Qt::Key_1
+         << Qt::Key_2
+         << Qt::Key_3
+         << Qt::Key_4
+         << Qt::Key_5
+         << Qt::Key_6
+         << Qt::Key_7
+         << Qt::Key_8
+         << Qt::Key_9;
+
+    QSignalMapper *selectMapper = new QSignalMapper(this);
+    QSignalMapper *saveMapper = new QSignalMapper(this);
+
+    mQuickStamps.resize(keys.size());
+
+    for (int i = 0; i < keys.length(); i++) {
+        // Set up shortcut for selecting this quick stamp
+        QShortcut *selectStamp = new QShortcut(this);
+        selectStamp->setKey(keys.value(i));
+        connect(selectStamp, SIGNAL(activated()), selectMapper, SLOT(map()));
+        selectMapper->setMapping(selectStamp, i);
+
+        // Set up shortcut for saving this quick stamp
+        QShortcut *saveStamp = new QShortcut(this);
+        saveStamp->setKey(QKeySequence(Qt::CTRL + keys.value(i)));
+        connect(saveStamp, SIGNAL(activated()), saveMapper, SLOT(map()));
+        saveMapper->setMapping(saveStamp, i);
+    }
+
+    connect(selectMapper, SIGNAL(mapped(int)), SLOT(selectQuickStamp(int)));
+    connect(saveMapper, SIGNAL(mapped(int)), SLOT(saveQuickStamp(int)));
+}
+
+void MainWindow::cleanQuickStamps()
+{
+    for (int i = 0; i < mQuickStamps.size(); i++)
+        eraseQuickStamp(i);
+}
+
+void MainWindow::eraseQuickStamp(int index)
+{
+    if (Map *quickStamp = mQuickStamps.at(index)) {
+        // Decrease reference to tilesets
+        TilesetManager *tilesetManager = TilesetManager::instance();
+        tilesetManager->removeReferences(quickStamp->tilesets());
+        delete quickStamp;
+    }
+}
+
+void MainWindow::selectQuickStamp(int index)
+{
+    if (!mMapDocument)
+        return;
+
+    if (Map *stampMap = mQuickStamps.at(index)) {
+        mMapDocument->unifyTilesets(stampMap);
+        setStampBrush(stampMap->layerAt(0)->asTileLayer());
+        ToolManager::instance()->selectTool(mStampBrush);
+    }
+}
+
+void MainWindow::saveQuickStamp(int index)
+{
+    const Map *map = mMapDocument->map();
+
+    // The source of the saved stamp depends on which tool is selected
+    AbstractTool *selectedTool = ToolManager::instance()->selectedTool();
+    TileLayer *copy = 0;
+    if (selectedTool == mStampBrush) {
+        TileLayer *stamp = mStampBrush->stamp();
+        if (!stamp)
+            return;
+
+        copy = static_cast<TileLayer*>(stamp->clone());
+    } else {
+        int currentLayer = mMapDocument->currentLayer();
+        if (currentLayer == -1)
+            return;
+
+        const TileLayer *tileLayer =
+                map->layerAt(currentLayer)->asTileLayer();
+        if (!tileLayer)
+            return;
+
+        const QRegion &selection = mMapDocument->tileSelection();
+        if (selection.isEmpty())
+            return;
+
+        copy = tileLayer->copy(selection.translated(-tileLayer->x(),
+                                                    -tileLayer->y()));
+    }
+
+    Map *copyMap = new Map(map->orientation(),
+                           copy->width(), copy->height(),
+                           map->tileWidth(), map->tileHeight());
+
+    copyMap->addLayer(copy);
+
+    // Add tileset references to map and tileset manager
+    TilesetManager *tilesetManager = TilesetManager::instance();
+    foreach (Tileset *tileset, copy->usedTilesets()) {
+        copyMap->addTileset(tileset);
+        tilesetManager->addReference(tileset);
+    }
+
+    eraseQuickStamp(index);
+    mQuickStamps.replace(index, copyMap);
+}
+
+void MainWindow::closeMapDocument(int index)
+{
+    mDocumentManager->switchToDocument(index);
+    if (confirmSave())
+        mDocumentManager->closeCurrentDocument();
+}
