@@ -26,6 +26,19 @@
 &lt;p align=&quot;center&quot;&gt;&lt;a href=&quot;http://www.mapeditor.org/&quot;&gt;http://www.mapeditor.org/&lt;/a&gt;&lt;/p&gt;</translation>
     </message>
 </context>
+<context>
+    <name>CommandDialog</name>
+    <message>
+        <location filename="../src/tiled/commanddialog.ui" line="+14"/>
+        <source>Properties</source>
+        <translation type="unfinished">プロパティ</translation>
+    </message>
+    <message>
+        <location line="+21"/>
+        <source>Save map before executing</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>MainWindow</name>
     <message>
@@ -34,7 +47,7 @@
         <translation>Tiled</translation>
     </message>
     <message>
-        <location line="+36"/>
+        <location line="+23"/>
         <source>&amp;File</source>
         <translation>ファイル(&amp;F)</translation>
     </message>
@@ -44,7 +57,7 @@
         <translation>最近使ったファイル(&amp;R)</translation>
     </message>
     <message>
-        <location line="+22"/>
+        <location line="+23"/>
         <source>&amp;Edit</source>
         <translation>編集(&amp;E)</translation>
     </message>
@@ -59,7 +72,7 @@
         <translation>マップ(&amp;M)</translation>
     </message>
     <message>
-        <location line="+12"/>
+        <location line="+13"/>
         <source>&amp;View</source>
         <translation>表示(&amp;V)</translation>
     </message>
@@ -68,7 +81,7 @@
         <translation type="obsolete">レイヤー(&amp;L)</translation>
     </message>
     <message>
-        <location line="+16"/>
+        <location line="+17"/>
         <source>Main Toolbar</source>
         <translation>メインツールバー</translation>
     </message>
@@ -88,7 +101,7 @@
         <translation>終了(&amp;Q)</translation>
     </message>
     <message>
-        <location line="+12"/>
+        <location line="+15"/>
         <source>&amp;Copy</source>
         <translation>コピー(&amp;C)</translation>
     </message>
@@ -103,12 +116,12 @@
         <translation>Tiledについて(&amp;A)</translation>
     </message>
     <message>
-        <location line="+5"/>
+        <location line="+8"/>
         <source>About Qt</source>
         <translation>Qtについて</translation>
     </message>
     <message>
-        <location line="+9"/>
+        <location line="+12"/>
         <source>&amp;Resize Map...</source>
         <translation>マップのサイズを変更(&amp;R)...</translation>
     </message>
@@ -117,6 +130,11 @@
         <source>Map &amp;Properties...</source>
         <translation>マップの設定(&amp;P)...</translation>
     </message>
+    <message>
+        <location line="+5"/>
+        <source>AutoMap</source>
+        <translation type="unfinished"></translation>
+    </message>
     <message>
         <location line="+8"/>
         <source>Show &amp;Grid</source>
@@ -138,7 +156,7 @@
         <translation>新しいファイル(&amp;N)...</translation>
     </message>
     <message>
-        <location line="+95"/>
+        <location line="+98"/>
         <source>&amp;Export As...</source>
         <translation>名前をつけてエクスポート(&amp;E)...</translation>
     </message>
@@ -152,6 +170,21 @@
         <source>&amp;Add External Tileset...</source>
         <translation>拡張タイルセットを追加(&amp;A)...</translation>
     </message>
+    <message>
+        <location line="+8"/>
+        <source>&amp;Snap to Grid</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location line="+5"/>
+        <source>C&amp;lose All</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location line="+3"/>
+        <source>Ctrl+Shift+W</source>
+        <translation type="unfinished"></translation>
+    </message>
     <message>
         <source>Move Layer &amp;Up</source>
         <translation type="obsolete">レイヤーの順番を上げる(&amp;U)</translation>
@@ -181,7 +214,7 @@
         <translation type="obsolete">新しいファイル...</translation>
     </message>
     <message>
-        <location line="-94"/>
+        <location line="-113"/>
         <source>New &amp;Tileset...</source>
         <translation>新しいタイルセット(&amp;T)...</translation>
     </message>
@@ -260,7 +293,7 @@
         <translation>設定(&amp;f)...</translation>
     </message>
     <message>
-        <location line="+9"/>
+        <location line="+12"/>
         <source>Clear Recent Files</source>
         <translation>最近使ったファイルをクリア</translation>
     </message>
@@ -280,19 +313,124 @@
         <translation type="obsolete">プロパティ(&amp;P)...</translation>
     </message>
     <message>
-        <location filename="../src/tiled/mapobjectitem.cpp" line="+265"/>
         <source>&amp;Duplicate Object</source>
-        <translation>オブジェクトを複製(&amp;D)</translation>
+        <translation type="obsolete">オブジェクトを複製(&amp;D)</translation>
     </message>
     <message>
-        <location line="+1"/>
         <source>&amp;Remove Object</source>
-        <translation>オブジェクトを削除(&amp;R)</translation>
+        <translation type="obsolete">オブジェクトを削除(&amp;R)</translation>
+    </message>
+    <message>
+        <source>Object &amp;Properties...</source>
+        <translation type="obsolete">オブジェクトのプロパティ(&amp;P)...</translation>
+    </message>
+</context>
+<context>
+    <name>MapReader</name>
+    <message>
+        <location filename="../src/libtiled/mapreader.cpp" line="+132"/>
+        <source>Not a map file.</source>
+        <translation type="unfinished">マップファイルではありません。</translation>
+    </message>
+    <message>
+        <location line="+19"/>
+        <source>Not a tileset file.</source>
+        <translation type="unfinished">タイルセットファイルではありません。</translation>
+    </message>
+    <message>
+        <location line="+11"/>
+        <source>%3
+
+Line %1, column %2</source>
+        <translation type="unfinished">%3
+
+行 %1, 位置 %2</translation>
+    </message>
+    <message>
+        <location line="+10"/>
+        <source>File not found: %1</source>
+        <translation type="unfinished">ファイルは見つかりませんでした: %1</translation>
     </message>
     <message>
         <location line="+3"/>
-        <source>Object &amp;Properties...</source>
-        <translation>オブジェクトのプロパティ(&amp;P)...</translation>
+        <source>Unable to read file: %1</source>
+        <translation type="unfinished">読み込めませんでした: %1</translation>
+    </message>
+    <message>
+        <location line="+61"/>
+        <source>Unsupported map orientation: &quot;%1&quot;</source>
+        <translation type="unfinished">マップの回転がサポートされていないものです: &quot;%1&quot;</translation>
+    </message>
+    <message>
+        <location line="+56"/>
+        <source>Invalid tileset parameters for tileset &apos;%1&apos;</source>
+        <translation type="unfinished">タイルセットのパラメータが不正です &apos;%1&apos;</translation>
+    </message>
+    <message>
+        <location line="+21"/>
+        <source>Error while loading tileset &apos;%1&apos;: %2</source>
+        <translation type="unfinished">タイルセットを読み込み中のエラーが発生しました &apos;%1&apos;: %2</translation>
+    </message>
+    <message>
+        <location line="+21"/>
+        <source>Invalid tile ID: %1</source>
+        <translation type="unfinished">タイルのIDが不正です: %1</translation>
+    </message>
+    <message>
+        <location line="+34"/>
+        <source>Error loading tileset image:
+&apos;%1&apos;</source>
+        <translation type="unfinished">タイルセットの画像を読み込み中にエラーが発生しました:
+&apos;%1&apos;</translation>
+    </message>
+    <message>
+        <location line="+64"/>
+        <source>Too many &lt;tile&gt; elements</source>
+        <translation type="unfinished">&lt;tile&gt; 要素が多すぎます</translation>
+    </message>
+    <message>
+        <location line="+11"/>
+        <location line="+66"/>
+        <location line="+39"/>
+        <location line="+103"/>
+        <source>Invalid tile: %1</source>
+        <translation type="unfinished">不正なタイル: %1</translation>
+    </message>
+    <message>
+        <location line="-188"/>
+        <source>Unknown encoding: %1</source>
+        <translation type="unfinished">エンコーディングがよく分かりません: %1</translation>
+    </message>
+    <message>
+        <location line="+19"/>
+        <source>Compression method &apos;%1&apos; not supported</source>
+        <translation type="unfinished">&apos;%1&apos;という圧縮方法には対応していません</translation>
+    </message>
+    <message>
+        <location line="+6"/>
+        <location line="+39"/>
+        <source>Corrupt layer data for layer &apos;%1&apos;</source>
+        <translation type="unfinished">レイヤー &apos;%1&apos; のデータが壊れています</translation>
+    </message>
+    <message>
+        <location line="+12"/>
+        <source>Unable to parse tile at (%1,%2) on layer &apos;%3&apos;</source>
+        <translation type="unfinished">レイヤー &apos;%3&apos;の(%1,%2)のタイルをパースできません</translation>
+    </message>
+    <message>
+        <location line="+20"/>
+        <source>Invalid global tile id (less than 0): %1</source>
+        <translation type="unfinished">グローバル・タイルIDが不正です (0未満): %1</translation>
+    </message>
+    <message>
+        <location line="+6"/>
+        <source>Tile used but no tilesets specified</source>
+        <translation type="unfinished">タイルセットが指定されていません</translation>
+    </message>
+    <message>
+        <location filename="../src/libtiled/mapwriter.cpp" line="+102"/>
+        <source>Could not open file for writing.</source>
+        <translation type="unfinished">書き込み用ファイルを開けませんでした.</translation>
     </message>
 </context>
 <context>
@@ -582,6 +720,11 @@
         <source>&amp;Language:</source>
         <translation>表示言語(&amp;L):</translation>
     </message>
+    <message>
+        <location line="+13"/>
+        <source>Hardware &amp;accelerated drawing (OpenGL)</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>PropertiesDialog</name>
@@ -594,7 +737,7 @@
 <context>
     <name>ResizeDialog</name>
     <message>
-        <location filename="../src/tiled/resizedialog.ui" line="+13"/>
+        <location filename="../src/tiled/resizedialog.ui" line="+14"/>
         <source>Resize</source>
         <translation>リサイズ</translation>
     </message>
@@ -672,32 +815,230 @@
         <translation>タイルのグリッドを描画(&amp;D)</translation>
     </message>
 </context>
+<context>
+    <name>Tengine::TenginePlugin</name>
+    <message>
+        <location filename="../src/plugins/tengine/tengineplugin.cpp" line="+50"/>
+        <source>Could not open file for writing.</source>
+        <translation type="unfinished">書き込み用ファイルを開けませんでした.</translation>
+    </message>
+    <message>
+        <location line="+243"/>
+        <source>T-Engine4 map files (*.lua)</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>Tiled::Internal::AutoMapper</name>
+    <message>
+        <location filename="../src/tiled/automap.cpp" line="+116"/>
+        <source>Multiple layers %1 found!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location line="+115"/>
+        <source>No ruleRegions layer found!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location line="+3"/>
+        <source>No set layers found!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location line="+3"/>
+        <source>No ruleSet layer found!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location line="+208"/>
+        <source>Tile</source>
+        <translation type="unfinished">タイル</translation>
+    </message>
+</context>
+<context>
+    <name>Tiled::Internal::AutomaticMappingManager</name>
+    <message>
+        <location line="+491"/>
+        <source>No set layer found!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location line="+29"/>
+        <source>Apply AutoMap rules</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location line="+18"/>
+        <source>No rules file found at:
+%1</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location line="+5"/>
+        <source>Error opening rules file:
+%1</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location line="+19"/>
+        <source>File not found:
+%1</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location line="+13"/>
+        <source>Opening rules map failed:
+%1</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>Tiled::Internal::BucketFillTool</name>
     <message>
         <location filename="../src/tiled/bucketfilltool.cpp" line="+39"/>
-        <location line="+139"/>
+        <location line="+133"/>
         <source>Bucket Fill Tool</source>
         <translation>塗りつぶし</translation>
     </message>
     <message>
-        <location line="-136"/>
-        <location line="+137"/>
+        <location line="-130"/>
+        <location line="+131"/>
         <source>F</source>
         <translation></translation>
     </message>
 </context>
+<context>
+    <name>Tiled::Internal::CommandButton</name>
+    <message>
+        <location filename="../src/tiled/commandbutton.cpp" line="+48"/>
+        <source>Execute Command</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location line="+1"/>
+        <source>F5</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location line="+39"/>
+        <location line="+61"/>
+        <source>Error Executing Command</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location line="-60"/>
+        <source>You do not have any commands setup.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location line="+2"/>
+        <source>Edit commands...</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location line="+50"/>
+        <source>Edit Commands...</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location line="+9"/>
+        <source>There was an error running the command</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>Tiled::Internal::CommandDataModel</name>
+    <message>
+        <location filename="../src/tiled/commanddatamodel.cpp" line="+74"/>
+        <source>Open in text editor</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location line="+90"/>
+        <location line="+67"/>
+        <source>&lt;new command&gt;</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location line="-59"/>
+        <source>Set a name for this command</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location line="+2"/>
+        <source>Set the shell command to execute</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location line="+2"/>
+        <source>Show or hide this command in the command list</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location line="+3"/>
+        <source>Add a new command</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location line="+100"/>
+        <source>Name</source>
+        <translation type="unfinished">名前</translation>
+    </message>
+    <message>
+        <location line="+1"/>
+        <source>Command</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location line="+1"/>
+        <source>Enable</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>Tiled::Internal::CommandDialog</name>
+    <message>
+        <location filename="../src/tiled/commanddialog.cpp" line="+35"/>
+        <source>Edit Commands</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>Tiled::Internal::CreateObjectTool</name>
+    <message>
+        <location filename="../src/tiled/createobjecttool.cpp" line="+42"/>
+        <location line="+111"/>
+        <source>O</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location line="-1"/>
+        <source>Insert Objects</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location line="+4"/>
+        <source>Insert Tile Objects</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location line="+1"/>
+        <source>T</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>Tiled::Internal::Eraser</name>
     <message>
         <location filename="../src/tiled/eraser.cpp" line="+34"/>
-        <location line="+37"/>
+        <location line="+36"/>
         <source>Eraser</source>
         <translation>消しゴム</translation>
     </message>
     <message>
-        <location line="-34"/>
-        <location line="+35"/>
+        <location line="-33"/>
+        <location line="+34"/>
         <source>E</source>
         <translation></translation>
     </message>
@@ -705,7 +1046,7 @@
 <context>
     <name>Tiled::Internal::LayerDock</name>
     <message>
-        <location filename="../src/tiled/layerdock.cpp" line="+165"/>
+        <location filename="../src/tiled/layerdock.cpp" line="+178"/>
         <source>Layers</source>
         <translation>レイヤー</translation>
     </message>
@@ -718,7 +1059,7 @@
 <context>
     <name>Tiled::Internal::LayerModel</name>
     <message>
-        <location filename="../src/tiled/layermodel.cpp" line="+114"/>
+        <location filename="../src/tiled/layermodel.cpp" line="+122"/>
         <source>Layer</source>
         <translation>レイヤー</translation>
     </message>
@@ -733,12 +1074,14 @@
 <context>
     <name>Tiled::Internal::MainWindow</name>
     <message>
-        <location filename="../src/tiled/mainwindow.cpp" line="+116"/>
+        <location filename="../src/tiled/mainwindow.cpp" line="+129"/>
+        <location line="+10"/>
         <source>Undo</source>
         <translation>元に戻す</translation>
     </message>
     <message>
-        <location line="+1"/>
+        <location line="-9"/>
+        <location line="+8"/>
         <source>Redo</source>
         <translation>やり直す</translation>
     </message>
@@ -747,13 +1090,13 @@
         <translation type="obsolete">マップを開くときにエラーが発生しました</translation>
     </message>
     <message>
-        <location line="+318"/>
+        <location line="+391"/>
         <source>Open Map</source>
         <translation>マップを開く</translation>
     </message>
     <message>
         <location line="-13"/>
-        <location line="+78"/>
+        <location line="+79"/>
         <source>Tiled map files (*.tmx)</source>
         <translation></translation>
     </message>
@@ -762,30 +1105,45 @@
         <translation type="obsolete">マップを保存中にエラーが発生しました</translation>
     </message>
     <message>
-        <location line="-338"/>
-        <location line="+835"/>
+        <location line="-425"/>
+        <source>Ctrl+=</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location line="+1"/>
+        <source>+</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location line="+3"/>
+        <source>-</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location line="+19"/>
+        <location line="+962"/>
         <source>&amp;Layer</source>
         <translation>レイヤー(&amp;L)</translation>
     </message>
     <message>
-        <location line="-611"/>
+        <location line="-711"/>
         <source>Error Opening Map</source>
         <translation>マップを開いている途中にエラー</translation>
     </message>
     <message>
-        <location line="+33"/>
-        <location line="+125"/>
+        <location line="+69"/>
+        <location line="+138"/>
         <source>All Files (*)</source>
         <translation>すべてのファイル (*)</translation>
     </message>
     <message>
-        <location line="-80"/>
-        <location line="+126"/>
+        <location line="-97"/>
+        <location line="+144"/>
         <source>Error Saving Map</source>
         <translation>マップを保存中にエラー</translation>
     </message>
     <message>
-        <location line="-95"/>
+        <location line="-108"/>
         <source>untitled.tmx</source>
         <translation>untitled.tmx</translation>
     </message>
@@ -800,12 +1158,12 @@
         <translation>変更が保存されていません。保存しますか?</translation>
     </message>
     <message>
-        <location line="+40"/>
+        <location line="+52"/>
         <source>Export As...</source>
         <translation>名前をつけてエクスポート...</translation>
     </message>
     <message>
-        <location line="+28"/>
+        <location line="+29"/>
         <source>Unknown File Format</source>
         <translation>不明のファイルフォーマット</translation>
     </message>
@@ -815,17 +1173,21 @@
         <translation>入力されたファイル名にサポートしている拡張子が含まれていません。</translation>
     </message>
     <message>
-        <location line="+43"/>
+        <location line="+47"/>
         <source>Cut</source>
         <translation>カット</translation>
     </message>
     <message>
-        <location line="+34"/>
-        <source>Add Tilesets</source>
-        <translation>タイルセットを追加</translation>
+        <location line="+377"/>
+        <source>[*]%1 - Tiled</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+50"/>
+        <source>Add Tilesets</source>
+        <translation type="obsolete">タイルセットを追加</translation>
+    </message>
+    <message>
+        <location line="-280"/>
         <source>Add External Tileset</source>
         <translation>拡張タイルセットを追加</translation>
     </message>
@@ -845,7 +1207,12 @@
         <translation>マップ</translation>
     </message>
     <message>
-        <location line="+114"/>
+        <location line="+12"/>
+        <source>Automatic Mapping</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location line="+123"/>
         <source>%1%</source>
         <translation></translation>
     </message>
@@ -866,16 +1233,19 @@
         <translation type="obsolete">新しいレイヤー</translation>
     </message>
     <message>
-        <location line="+69"/>
-        <location line="+46"/>
         <source>%1[*] - Tiled</source>
-        <translation>%1[*] - Tiled</translation>
+        <translation type="obsolete">%1[*] - Tiled</translation>
     </message>
 </context>
 <context>
     <name>Tiled::Internal::MapDocument</name>
     <message>
-        <location filename="../src/tiled/mapdocument.cpp" line="+109"/>
+        <location filename="../src/tiled/mapdocument.cpp" line="+105"/>
+        <source>untitled.tmx</source>
+        <translation type="unfinished">untitled.tmx</translation>
+    </message>
+    <message>
+        <location line="+39"/>
         <source>Resize Map</source>
         <translation>マップのリサイズ</translation>
     </message>
@@ -904,6 +1274,16 @@
         <source>Duplicate Layer</source>
         <translation>レイヤーの複製</translation>
     </message>
+    <message>
+        <location line="+120"/>
+        <source>Tile</source>
+        <translation type="unfinished">タイル</translation>
+    </message>
+    <message>
+        <location line="+10"/>
+        <source>Tileset Changes</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>Tiled::Internal::MapDocumentActionHandler</name>
@@ -984,7 +1364,7 @@
 <context>
     <name>Tiled::Internal::NewTilesetDialog</name>
     <message>
-        <location filename="../src/tiled/newtilesetdialog.cpp" line="+115"/>
+        <location filename="../src/tiled/newtilesetdialog.cpp" line="+123"/>
         <location line="+7"/>
         <source>Error</source>
         <translation>エラー</translation>
@@ -1039,11 +1419,62 @@
         <translation>オブジェクトを変更</translation>
     </message>
 </context>
+<context>
+    <name>Tiled::Internal::ObjectSelectionTool</name>
+    <message>
+        <location filename="../src/tiled/objectselectiontool.cpp" line="+103"/>
+        <location line="+135"/>
+        <source>Select Objects</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location line="-132"/>
+        <location line="+133"/>
+        <source>S</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message numerus="yes">
+        <location line="+77"/>
+        <location line="+145"/>
+        <source>Duplicate %n Object(s)</source>
+        <translation type="unfinished">
+            <numerusform></numerusform>
+        </translation>
+    </message>
+    <message numerus="yes">
+        <location line="-144"/>
+        <location line="+162"/>
+        <source>Remove %n Object(s)</source>
+        <translation type="unfinished">
+            <numerusform></numerusform>
+        </translation>
+    </message>
+    <message numerus="yes">
+        <location line="-153"/>
+        <location line="+163"/>
+        <source>Move %n Object(s) to Layer</source>
+        <translation type="unfinished">
+            <numerusform></numerusform>
+        </translation>
+    </message>
+    <message>
+        <location line="-153"/>
+        <source>Object &amp;Properties...</source>
+        <translation type="unfinished">オブジェクトのプロパティ(&amp;P)...</translation>
+    </message>
+    <message numerus="yes">
+        <location line="+107"/>
+        <source>Move %n Object(s)</source>
+        <translation type="unfinished">
+            <numerusform></numerusform>
+        </translation>
+    </message>
+</context>
 <context>
     <name>Tiled::Internal::PreferencesDialog</name>
     <message>
-        <location filename="../src/tiled/preferencesdialog.cpp" line="+45"/>
-        <location line="+22"/>
+        <location filename="../src/tiled/preferencesdialog.cpp" line="+56"/>
+        <location line="+23"/>
         <source>System default</source>
         <translation>システム標準</translation>
     </message>
@@ -1051,12 +1482,12 @@
 <context>
     <name>Tiled::Internal::PropertiesDialog</name>
     <message>
-        <location filename="../src/tiled/propertiesdialog.cpp" line="+61"/>
+        <location filename="../src/tiled/propertiesdialog.cpp" line="+62"/>
         <source>%1 Properties</source>
         <translation>%1 プロパティ</translation>
     </message>
     <message>
-        <location line="+31"/>
+        <location line="+37"/>
         <source>Layer</source>
         <translation>レイヤー</translation>
     </message>
@@ -1064,13 +1495,12 @@
 <context>
     <name>Tiled::Internal::PropertiesModel</name>
     <message>
-        <location filename="../src/tiled/propertiesmodel.cpp" line="+50"/>
-        <location line="+24"/>
+        <location filename="../src/tiled/propertiesmodel.cpp" line="+51"/>
         <source>&lt;new property&gt;</source>
         <translation>&lt;新しいプロパティ&gt;</translation>
     </message>
     <message>
-        <location line="+44"/>
+        <location line="+68"/>
         <source>Name</source>
         <translation>名前</translation>
     </message>
@@ -1104,18 +1534,18 @@ Do you want to replace it?</source>
     <name>Tiled::Internal::SelectionTool</name>
     <message>
         <location filename="../src/tiled/selectiontool.cpp" line="+34"/>
-        <location line="+80"/>
+        <location line="+81"/>
         <source>Rectangular Select</source>
         <translation>選択範囲</translation>
     </message>
     <message>
-        <location line="-77"/>
-        <location line="+78"/>
+        <location line="-78"/>
+        <location line="+79"/>
         <source>R</source>
         <translation></translation>
     </message>
     <message>
-        <location line="-55"/>
+        <location line="-56"/>
         <source>%1, %2 - Rectangle: (%3 x %4)</source>
         <translation>%1, %2 - 四角形: (%3 x %4)</translation>
     </message>
@@ -1123,14 +1553,14 @@ Do you want to replace it?</source>
 <context>
     <name>Tiled::Internal::StampBrush</name>
     <message>
-        <location filename="../src/tiled/stampbrush.cpp" line="+34"/>
-        <location line="+58"/>
+        <location filename="../src/tiled/stampbrush.cpp" line="+38"/>
+        <location line="+279"/>
         <source>Stamp Brush</source>
         <translation>スタンプ</translation>
     </message>
     <message>
-        <location line="-55"/>
-        <location line="+56"/>
+        <location line="-276"/>
+        <location line="+277"/>
         <source>B</source>
         <translation></translation>
     </message>
@@ -1138,7 +1568,7 @@ Do you want to replace it?</source>
 <context>
     <name>Tiled::Internal::TilesetDock</name>
     <message>
-        <location filename="../src/tiled/tilesetdock.cpp" line="+236"/>
+        <location filename="../src/tiled/tilesetdock.cpp" line="+247"/>
         <source>Remove Tileset</source>
         <translation>タイルセットを削除</translation>
     </message>
@@ -1153,7 +1583,7 @@ Do you want to replace it?</source>
         <translation>このタイルセットを削除し、タイル使用部分をすべて取り除いてよろしいですか?</translation>
     </message>
     <message>
-        <location line="+49"/>
+        <location line="+58"/>
         <source>Tilesets</source>
         <translation>タイルセット</translation>
     </message>
@@ -1165,7 +1595,7 @@ Do you want to replace it?</source>
         <translation type="obsolete">プロパティ...</translation>
     </message>
     <message>
-        <location filename="../src/tiled/tilesetview.cpp" line="+207"/>
+        <location filename="../src/tiled/tilesetview.cpp" line="+210"/>
         <source>Tile &amp;Properties...</source>
         <translation>タイルの設定(&amp;P)...</translation>
     </message>
@@ -1198,7 +1628,7 @@ Do you want to replace it?</source>
 <context>
     <name>Tiled::Internal::ToolManager</name>
     <message>
-        <location filename="../src/tiled/toolmanager.cpp" line="+87"/>
+        <location filename="../src/tiled/toolmanager.cpp" line="+88"/>
         <source>Tools</source>
         <translation>ツール</translation>
     </message>
@@ -1246,13 +1676,12 @@ Do you want to replace it?</source>
 <context>
     <name>TmxMapReader</name>
     <message>
-        <location filename="../src/tiled/tmxmapwriter.cpp" line="+48"/>
         <source>Could not open file for writing.</source>
-        <translation>書き込み用ファイルを開けませんでした.</translation>
+        <translation type="obsolete">書き込み用ファイルを開けませんでした.</translation>
     </message>
     <message>
         <location filename="../src/tiled/tmxmapreader.h" line="+55"/>
-        <location filename="../src/tiled/tmxmapwriter.h" line="+67"/>
+        <location filename="../src/tiled/tmxmapwriter.h" line="+56"/>
         <source>Tiled map files (*.tmx)</source>
         <translation>Tiledマップファイル (*.tmx)</translation>
     </message>
@@ -1260,104 +1689,90 @@ Do you want to replace it?</source>
 <context>
     <name>TmxReader</name>
     <message>
-        <location filename="../src/tiled/tmxmapreader.cpp" line="+139"/>
-        <location line="+21"/>
         <source>Not a map file.</source>
-        <translation>マップファイルではありません。</translation>
+        <translation type="obsolete">マップファイルではありません。</translation>
     </message>
     <message>
-        <location line="+21"/>
         <source>Not a tileset file.</source>
-        <translation>タイルセットファイルではありません。</translation>
+        <translation type="obsolete">タイルセットファイルではありません。</translation>
     </message>
     <message>
-        <location line="+15"/>
         <source>%3
 
 Line %1, column %2</source>
-        <translation>%3
+        <translation type="obsolete">%3
 
 行 %1, 位置 %2</translation>
     </message>
     <message>
-        <location line="+10"/>
         <source>File not found: %1</source>
-        <translation>ファイルは見つかりませんでした: %1</translation>
+        <translation type="obsolete">ファイルは見つかりませんでした: %1</translation>
     </message>
     <message>
-        <location line="+3"/>
         <source>Unable to read file: %1</source>
-        <translation>読み込めませんでした: %1</translation>
+        <translation type="obsolete">読み込めませんでした: %1</translation>
     </message>
     <message>
-        <location line="+61"/>
         <source>Unsupported map orientation: &quot;%1&quot;</source>
-        <translation>マップの回転がサポートされていないものです: &quot;%1&quot;</translation>
+        <translation type="obsolete">マップの回転がサポートされていないものです: &quot;%1&quot;</translation>
     </message>
     <message>
-        <location line="+56"/>
         <source>Invalid tileset parameters for tileset &apos;%1&apos;</source>
-        <translation>タイルセットのパラメータが不正です &apos;%1&apos;</translation>
+        <translation type="obsolete">タイルセットのパラメータが不正です &apos;%1&apos;</translation>
     </message>
     <message>
-        <location line="+54"/>
         <source>Error while loading tileset &apos;%1&apos;: %2</source>
-        <translation>タイルセットを読み込み中のエラーが発生しました &apos;%1&apos;: %2</translation>
+        <translation type="obsolete">タイルセットを読み込み中のエラーが発生しました &apos;%1&apos;: %2</translation>
     </message>
     <message>
-        <location line="+22"/>
         <source>Invalid tile ID: %1</source>
-        <translation>タイルのIDが不正です: %1</translation>
+        <translation type="obsolete">タイルのIDが不正です: %1</translation>
     </message>
     <message>
-        <location line="+33"/>
         <source>Error loading tileset image:
 &apos;%1&apos;</source>
-        <translation>タイルセットの画像を読み込み中にエラーが発生しました:
+        <translation type="obsolete">タイルセットの画像を読み込み中にエラーが発生しました:
 &apos;%1&apos;</translation>
     </message>
     <message>
-        <location line="+49"/>
         <source>Too many &lt;tile&gt; elements</source>
-        <translation>&lt;tile&gt; 要素が多すぎます</translation>
+        <translation type="obsolete">&lt;tile&gt; 要素が多すぎます</translation>
     </message>
     <message>
-        <location line="+11"/>
-        <location line="+66"/>
-        <location line="+39"/>
         <source>Invalid tile: %1</source>
-        <translation>不正なタイル: %1</translation>
+        <translation type="obsolete">不正なタイル: %1</translation>
     </message>
     <message>
-        <location line="-85"/>
         <source>Unknown encoding: %1</source>
-        <translation>エンコーディングがよく分かりません: %1</translation>
+        <translation type="obsolete">エンコーディングがよく分かりません: %1</translation>
     </message>
     <message>
-        <location line="+19"/>
         <source>Compression method &apos;%1&apos; not supported</source>
-        <translation>&apos;%1&apos;という圧縮方法には対応していません</translation>
+        <translation type="obsolete">&apos;%1&apos;という圧縮方法には対応していません</translation>
     </message>
     <message>
-        <location line="+6"/>
-        <location line="+39"/>
         <source>Corrupt layer data for layer &apos;%1&apos;</source>
-        <translation>レイヤー &apos;%1&apos; のデータが壊れています</translation>
+        <translation type="obsolete">レイヤー &apos;%1&apos; のデータが壊れています</translation>
     </message>
     <message>
-        <location line="+12"/>
         <source>Unable to parse tile at (%1,%2) on layer &apos;%3&apos;</source>
-        <translation>レイヤー &apos;%3&apos;の(%1,%2)のタイルをパースできません</translation>
+        <translation type="obsolete">レイヤー &apos;%3&apos;の(%1,%2)のタイルをパースできません</translation>
     </message>
     <message>
-        <location line="+20"/>
         <source>Invalid global tile id (less than 0): %1</source>
-        <translation>グローバル・タイルIDが不正です (0未満): %1</translation>
+        <translation type="obsolete">グローバル・タイルIDが不正です (0未満): %1</translation>
     </message>
     <message>
-        <location line="+6"/>
         <source>Tile used but no tilesets specified</source>
-        <translation>タイルセットが指定されていません</translation>
+        <translation type="obsolete">タイルセットが指定されていません</translation>
+    </message>
+</context>
+<context>
+    <name>TmxViewer</name>
+    <message>
+        <location filename="../src/tmxviewer/tmxviewer.cpp" line="+166"/>
+        <source>TMX Viewer</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
@@ -1394,7 +1809,7 @@ Line %1, column %2</source>
         <translation>オブジェクト・レイヤーのプロパティを変更</translation>
     </message>
     <message>
-        <location filename="../src/tiled/changeproperties.cpp" line="+33"/>
+        <location filename="../src/tiled/changeproperties.cpp" line="+34"/>
         <source>Change %1 Properties</source>
         <translation>%1 プロパティを変更</translation>
     </message>
@@ -1474,7 +1889,7 @@ Line %1, column %2</source>
         <translation>タイルセットを移動</translation>
     </message>
     <message>
-        <location filename="../src/tiled/tilesetview.cpp" line="-147"/>
+        <location filename="../src/tiled/tilesetview.cpp" line="-151"/>
         <source>Import Tileset</source>
         <translation>タイルセットをインポート</translation>
     </message>
@@ -1483,11 +1898,16 @@ Line %1, column %2</source>
         <source>Export Tileset</source>
         <translation>タイルセットをエクスポート</translation>
     </message>
+    <message>
+        <location filename="../src/tiled/movemapobjecttogroup.cpp" line="+40"/>
+        <source>Move Object to Layer</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>Utils</name>
     <message>
-        <location filename="../src/tiled/utils.cpp" line="+32"/>
+        <location filename="../src/tiled/utils.cpp" line="+31"/>
         <source>Image files</source>
         <translation>画像ファイル</translation>
     </message>
